# covid19.py

Track the COVID-19 data in all the countries in the world from the command line.

It is a [python](www.python.org) script inspired by [ahmadawais/corona-cli](https://github.com/ahmadawais/corona-cli) and it used the data from [NovelCOVID](https://github.com/NovelCOVID/API)

### Installation

```
pip install covid19.py
```

### Run

Show the first 10 countries by 10 cases:

```
covid19.py -m 10
```

![covid19](https://github.com/alexcoppe/covid19.py/blob/master/covid19.png)

Show the help:

```
covid19.py -h
```



### Licence

DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE, version 2, December 2004.

<a href="http://www.wtfpl.net/"><img
       src="http://www.wtfpl.net/wp-content/uploads/2012/12/wtfpl-badge-1.png"
       width="88" height="31" alt="WTFPL" />
</a>
